%define upstream_name    Mail-DKIM
%define upstream_version 1.20230212

%{?perl_default_filter}

Name:       perl-%{upstream_name}
Version:    %perl_convert_version %{upstream_version}.0
Release:    %mkrel 1
Summary:    Implements DomainKeys Identified Mail (DKIM)
License:    GPL+ or Artistic
Group:      Development/Perl
Url:        https://metacpan.org/release/%{upstream_name}
Source0:    https://cpan.metacpan.org/modules/by-module/Mail/%{upstream_name}-%{upstream_version}.tar.gz

BuildRequires: perl(Carp)
BuildRequires: perl(Crypt::OpenSSL::RSA)
BuildRequires: perl(Data::Dumper)
BuildRequires: perl(Digest::SHA)
BuildRequires: perl(ExtUtils::MakeMaker)
BuildRequires: perl(MIME::Base64)
BuildRequires: perl(Mail::Address)
BuildRequires: perl(Mail::AuthenticationResults::Header::AuthServID)
BuildRequires: perl(Mail::AuthenticationResults::Parser)
BuildRequires: perl(Net::DNS)
BuildRequires: perl(Net::DNS::Resolver)
BuildRequires: perl(Net::DNS::Resolver::Mock)
BuildRequires: perl(Test::More)
BuildRequires: perl(Test::RequiresInternet)
BuildRequires: perl(Test::Simple)
BuildRequires: perl(YAML::XS)
BuildRequires: perl(base)
BuildRequires: perl(lib)
BuildRequires: perl(strict)
BuildRequires: perl(warnings)
BuildArch:  noarch

%description
This module implements the various components of the DKIM and DomainKeys
message-signing and verifying standards for Internet mail. It currently
tries to implement these specifications:
 * RFC4871, for DKIM
 * RFC4870, for DomainKeys

%prep
%setup -q -n %{upstream_name}-%{upstream_version}

%build
%{__perl} Makefile.PL INSTALLDIRS=vendor
%make_build

%check
# Conditionally disable tests that require DNS lookups
%{?!_with_network_tests: rm t/policy.t t/public_key.t }
%__make test

%install
%make_install

%files
%doc Changes LICENSE META.json META.yml MYMETA.yml README TODO
%dir %{perl_vendorlib}/Mail/DKIM
%dir %{perl_vendorlib}/Mail/DKIM/Algorithm
%dir %{perl_vendorlib}/Mail/DKIM/Canonicalization
%{perl_vendorlib}/Mail/DKIM/*.pm
%{perl_vendorlib}/Mail/DKIM/ARC
%{perl_vendorlib}/Mail/DKIM/Algorithm/*.pm
%{perl_vendorlib}/Mail/DKIM/Canonicalization/*.pm
%{perl_vendorlib}/Mail/DKIM.pm
%{_mandir}/man3/*

%changelog
* Wed Feb 22 2023 tv <tv> 1.20230212.0-1.mga9
+ Revision: 1944688
- update to 1.20230212

* Tue Apr 12 2022 tv <tv> 1.20220408.0-1.mga9
+ Revision: 1848972
- update to 1.20220408

* Mon Mar 21 2022 umeabot <umeabot> 1.20200907.0-2.mga9
+ Revision: 1813765
- Mageia 9 Mass Rebuild

* Tue Dec 22 2020 guillomovitch <guillomovitch> 1.20200907.0-1.mga8
+ Revision: 1662996
- new version 20200907

* Sat Sep 05 2020 guillomovitch <guillomovitch> 1.20200824.0-1.mga8
+ Revision: 1622609
- new version 1.20200824

* Tue Jul 14 2020 tv <tv> 1.20200708.0-1.mga8
+ Revision: 1605990
- add .0 to version in order to workaround %%perl_convert_version "downgrade"
- 1.20200708

* Thu May 14 2020 tv <tv> 1.20200513.1-1.mga8
+ Revision: 1583644
- update to 1.20200513.1

* Tue Feb 18 2020 umeabot <umeabot> 0.580.0-2.mga8
+ Revision: 1538110
- Mageia 8 Mass Rebuild

* Wed Nov 13 2019 tv <tv> 0.580.0-1.mga8
+ Revision: 1459838
- update to 0.58

* Mon Oct 07 2019 tv <tv> 0.570.0-1.mga8
+ Revision: 1450122
- update to 0.57

* Sun Aug 25 2019 tv <tv> 0.560.0-1.mga8
+ Revision: 1431976
- update to 0.56

* Wed Apr 17 2019 shlomif <shlomif> 0.550.0-1.mga7
+ Revision: 1392483
- New version

* Sun Oct 14 2018 tv <tv> 0.540.0-1.mga7
+ Revision: 1320232
- update to 0.54

* Thu Sep 20 2018 umeabot <umeabot> 0.530.0-2.mga7
+ Revision: 1284710
- Mageia 7 Mass Rebuild

* Sun May 27 2018 tv <tv> 0.530.0-1.mga7
+ Revision: 1232590
- update to 0.53

* Sat Jan 13 2018 tv <tv> 0.520.0-1.mga7
+ Revision: 1192627
- update to 0.52

* Sun Dec 17 2017 tv <tv> 0.500.0-1.mga7
+ Revision: 1182993
- update to 0.50
- update to 0.44

* Sat Oct 28 2017 tv <tv> 0.440.0-1.mga7
+ Revision: 1174395
- new release

* Tue Oct 03 2017 tv <tv> 0.430.0-2.mga7
+ Revision: 1165285
- rebuild with fixed rpm for missing autodeps

* Wed Sep 20 2017 tv <tv> 0.430.0-1.mga7
+ Revision: 1156471
- update to 0.43

* Tue Sep 19 2017 tv <tv> 0.420.0-1.mga7
+ Revision: 1155848
- new release

* Sat Jul 22 2017 shlomif <shlomif> 0.410.0-1.mga7
+ Revision: 1128729
- update to 0.41

* Sun Jun 19 2016 pterjan <pterjan> 0.400.0-7.mga6
+ Revision: 1029498
- Rebuild for perl 5.22.2

* Mon Feb 08 2016 umeabot <umeabot> 0.400.0-6.mga6
+ Revision: 949490
- Mageia 6 Mass Rebuild

* Sun Oct 19 2014 umeabot <umeabot> 0.400.0-5.mga5
+ Revision: 789872
- Rebuild to potentially add missing dependencies

* Wed Oct 15 2014 umeabot <umeabot> 0.400.0-4.mga5
+ Revision: 739092
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 0.400.0-3.mga5
+ Revision: 685310
- Mageia 5 Mass Rebuild

* Sat Oct 19 2013 umeabot <umeabot> 0.400.0-2.mga4
+ Revision: 527102
- Mageia 4 Mass Rebuild

* Fri Jun 07 2013 jquelin <jquelin> 0.400.0-1.mga4
+ Revision: 439512
- update to 0.40

* Sun Jan 13 2013 umeabot <umeabot> 0.390.0-2.mga3
+ Revision: 369402
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Jan 22 2011 ennael <ennael> 0.390.0-1.mga1
+ Revision: 33072
- remove mdkversion
+ jquelin <jquelin>
- imported package perl-Mail-DKIM

